@@ -1,8 +1,4 @@
 import datetime
-from typing import List, Tuple
-from urllib.parse import urlparse, parse_qs
-
-from bs4 import BeautifulSoup
 
 from .source import Source
 from ...models import Chapter, Novel, Metadata
@@ -11,7 +7,7 @@ from ...models import Chapter, Novel, Metadata
 class DragonTea(Source):
     name = 'Dragon Tea'
     base_urls = ('https://dragontea.ink/',)
-    last_updated = datetime.date(2021, 8, 20)
+    last_updated = datetime.date(2021, 9, 7)
 
     bad_tags = [
         'noscript', 'script', 'iframe', 'form', 'hr', 'img', 'ins',
@@ -19,63 +15,48 @@ class DragonTea(Source):
         'h1', 'h2', 'h3', 'h4', 'h5', 'h6',
     ]
 
-    def novel(self, url: str) -> Tuple[Novel, List[Chapter], List[Metadata]]:
+    def novel(self, url: str) -> Novel:
         soup = self.get_soup(url)
 
-        summary_paragraphs = [p.text.strip() for p in soup.select('.summary__content > p')]
-
         novel = Novel(
             title=soup.select_one('.post-title').text.strip(),
             author=soup.select_one('.author-content').text.strip(),
-            thumbnail_url=soup.select_one('.summary_image img')['src'],
-            synopsis='\n'.join(summary_paragraphs),
+            thumbnail_url=self.to_absolute_url(soup.select_one('.summary_image img')['src'], url),
+            synopsis=[p.text.strip() for p in soup.select('.summary__content > p')],
             url=url,
         )
 
         # other metadata
-        metadata = []
         for item in soup.select('.post-content_item'):
             key = item.select_one('.summary-heading').text.strip()
             value = item.select_one('.summary-content').text.strip()
             if key == 'Alternative':
-                metadata.append(Metadata('title', value, others={'role': 'alt'}))
+                novel.metadata.append(Metadata('title', value, others={'role': 'alt'}))
             elif key == 'Type':
-                metadata.append(Metadata('type', value))
+                novel.metadata.append(Metadata('type', value))
 
         for a in soup.select('.genres-content > a'):
-            metadata.append(Metadata('subject', a.text.strip()))
+            novel.metadata.append(Metadata('subject', a.text.strip()))
 
         for a in soup.select('.tags-content > a'):
-            metadata.append(Metadata('tag', a.text.strip()))
+            novel.metadata.append(Metadata('tag', a.text.strip()))
 
         artist_content = soup.select_one('.artist-content > a')
         if artist_content:
-            metadata.append(Metadata('contributor', artist_content.text.strip(),
-                                     others={'role': 'ill', 'link': artist_content['href']}))
+            novel.metadata.append(Metadata('contributor', artist_content.text.strip(), others={'role': 'ill'}))
 
-        short_link = soup.select_one('[rel="shortlink"]')['href']
-        novel_id = int(parse_qs(urlparse(short_link).query)['p'][0])
-        response = self.session.post(
-            'https://dragontea.ink/wp-admin/admin-ajax.php',
-            data={
-                'action': 'manga_get_chapters',
-                'manga': novel_id,
-            }
-        )
-
-        soup = BeautifulSoup(response.content, 'lxml')
-
-        chapters = []
+        soup = self.get_soup(url.rstrip('/') + '/ajax/chapters/', method='POST')
+        volume = novel.get_default_volume()
         for a in reversed(soup.select('.wp-manga-chapter > a')):
             chapter = Chapter(
-                index=len(chapters),
+                index=len(volume.chapters),
                 title=a.text.strip(),
-                url=a['href'],
+                url=self.to_absolute_url(a['href']),
             )
 
-            chapters.append(chapter)
+            volume.chapters.append(chapter)
 
-        return novel, chapters, metadata
+        return novel
 
     def chapter(self, chapter: Chapter):
         soup = self.get_soup(chapter.url)
