@@ -1,5 +1,4 @@
 import datetime
-from typing import List, Tuple
 
 from .source import Source
 from ...models import Chapter, Novel, Metadata
@@ -7,10 +6,13 @@ from ...models import Chapter, Novel, Metadata
 
 class MtlNovel(Source):
     name = 'MTL Novel'
-    base_urls = ('https://www.mtlnovel.com',)
-    last_updated = datetime.date(2021, 8, 30)
+    base_urls = (
+        'https://www.mtlnovel.com',
+        'http://www.mtlnovel.com',
+    )
+    last_updated = datetime.date(2021, 9, 7)
 
-    def novel(self, url: str) -> Tuple[Novel, List[Chapter], List[Metadata]]:
+    def novel(self, url: str) -> Novel:
         http_url = url.replace('https://', 'http://')
         soup = self.get_soup(http_url)
 
@@ -25,30 +27,29 @@ class MtlNovel(Source):
         novel = Novel(
             title=soup.select_one('.entry-title').text.strip(),
             author=author,
-            synopsis='\n'.join(p.text.strip() for p in soup.select('.desc > p:not(.descr)')),
+            synopsis=[p.text.strip() for p in soup.select('.desc > p:not(.descr)')],
             thumbnail_url=soup.select_one('.main-tmb')['src'],
             url=url,
         )
 
         # metadata
-        metadata = []
         alt_title = soup.select_one('#alt')
         if alt_title:
-            metadata.append(Metadata('title', alt_title.text.strip(), others={'role': 'alt'}))
+            novel.metadata.append(Metadata('title', alt_title.text.strip(), others={'role': 'alt'}))
 
         for genre in soup.select('#genre a'):
-            metadata.append(Metadata('subject', genre.text.strip()))
+            novel.metadata.append(Metadata('subject', genre.text.strip()))
 
         for tag in soup.select('#tags a:not(.edit-history-button)'):
-            metadata.append(Metadata('tag', tag.text.strip()))
+            novel.metadata.append(Metadata('tag', tag.text.strip()))
 
-        metadata.append(Metadata('status', soup.select_one('#status').text.strip()))
+        novel.metadata.append(Metadata('status', soup.select_one('#status').text.strip()))
 
         # chapter list
         chapter_list_url = http_url.rstrip('/') + '/chapter-list/'
         soup = self.get_soup(chapter_list_url)
 
-        chapters = []
+        volume = novel.get_default_volume()
         for i, a in enumerate(reversed(soup.select('.ch-list .ch-link'))):
 
             chapter = Chapter(
@@ -57,9 +58,9 @@ class MtlNovel(Source):
                 url=a['href'],
             )
 
-            chapters.append(chapter)
+            volume.chapters.append(chapter)
 
-        return novel, chapters, metadata
+        return novel
 
     def chapter(self, chapter: Chapter):
         soup = self.get_soup(chapter.url)
@@ -68,7 +69,7 @@ class MtlNovel(Source):
         self.clean_contents(paragraphs)
 
         # remove ad frames
-        for frame in paragraphs.select('amp-iframe'):
+        for frame in paragraphs.select('amp-iframe, .ads'):
             frame.decompose()
 
         chapter.title = soup.select_one('.current-crumb').text.strip()
