@@ -1,17 +1,10 @@
+import datetime
 import re
-from typing import Tuple, List
-
-import requests
 
 from .source import Source
 from ...models import Novel, Chapter, Metadata
 
-
-class NovelFun(Source):
-    base_urls = ('https://novelfun.net',)
-    graphql = f'{base_urls[0]}/graphql'
-
-    query = """query chapters_NovelRefetchQuery(
+query = """query chapters_NovelRefetchQuery(
     $slug: String!
     $startChapNum: Int
 ) {...chapters_list_items} fragment chapters_list_items on Query {
@@ -29,44 +22,50 @@ class NovelFun(Source):
 }
 """
 
-    def novel(self, url: str) -> Tuple[Novel, List[Chapter], List[Metadata]]:
+
+class NovelFun(Source):
+    base_urls = ('https://novelfun.net',)
+    last_updated = datetime.date(2021, 9, 7)
+
+    graphql = f'{base_urls[0]}/graphql'
+
+    def novel(self, url: str) -> Novel:
         soup = self.get_soup(url)
-        metadata = []
 
         novel = Novel(
             title=soup.select_one('h1').text.strip(),
             author=soup.select_one('a[href*="author"]').text.strip(),
-            synopsis='\n'.join([p.text.strip() for p in soup.select('article > div > p')]),
+            synopsis=[p.text.strip() for p in soup.select('article > div > p')],
             url=url,
         )
 
         novel.thumbnail_url = soup.select_one(f'img[title="{novel.title}"]')['src']
 
         for a in soup.select('td a[href*="genre"]'):
-            metadata.append(Metadata('subject', a.text.strip()))
+            novel.metadata.append(Metadata('subject', a.text.strip()))
 
         title_slug = url.rstrip('/').split('/')[-1]
         total = int(re.match(r'(\d+)', soup.select_one('h2 ~ div').text).group(1))
         data = {
             'id_': 'chapters_NovelRefetchQuery',
-            'query': self.query % total,
+            'query': query % total,
             'variables': {
                 'slug': title_slug,
                 'startChapNum': 1,
             },
         }
-        response = requests.get(self.graphql, json=data)
+        data = self.session.get(self.graphql, json=data).json()
 
-        chapters = [
+        novel.get_default_volume().chapters = [
             Chapter(
                 index=c['chapNum'],
-                title=c["title"],
+                title=f'Chapter {c["chapNum"]}: {c["title"]}',
                 url=self.base_urls[0]+c['url'],
             )
-            for c in response.json()['data']['chapterListChunks'][0]['items']
+            for c in data['data']['chapterListChunks'][0]['items']
         ]
 
-        return novel, chapters, metadata
+        return novel
 
     def chapter(self, chapter: Chapter):
         soup = self.get_soup(chapter.url)
