@@ -1,4 +1,4 @@
-from typing import List, Tuple
+import datetime
 
 from .source import Source
 from ...models import Chapter, Novel, Metadata
@@ -7,56 +7,43 @@ from ...models import Chapter, Novel, Metadata
 class PeachPitting(Source):
     name = 'Peach Pits'
     base_urls = ('https://peachpitting.com',)
+    last_updated = datetime.date(2021, 9, 4)
 
-    bad_tags = [
-        'noscript', 'script', 'iframe', 'form', 'img', 'ins',
-        'button', 'input', 'amp-auto-ads', 'pirate', 'ul'
-    ]
-
-    def novel(self, url: str) -> Tuple[Novel, List[Chapter], List[Metadata]]:
+    def novel(self, url: str) -> Novel:
         soup = self.get_soup(url)
-        metadata = []
 
         details_parent, synopsis_parent, *_ = soup.select('.elementor-text-editor')
 
-        author = None
-        subjects = []
-        for p in details_parent.select('p'):
-            text = p.text.strip()
-            if text.startswith('Author: '):
-                author = text.strip('Author: ')
-            elif text.startswith('Tags: '):
-                subjects = [s.strip() for s in text.strip('Tags: ').split(',')]
-
-        synopsis = '\n'.join([p.text.strip() for p in synopsis_parent.select('p')])
-
         novel = Novel(
             title=soup.select_one('h3.elementor-heading-title').text.strip(),
             thumbnail_url=soup.select_one('.elementor-image img')['src'],
-            synopsis=synopsis,
-            author=author,
+            synopsis=[p.text.strip() for p in synopsis_parent.select('p')],
             url=url,
         )
 
-        # tags
-        for subject in subjects:
-            metadata.append(Metadata('subject', subject))
+        for p in details_parent.select('p'):
+            text = p.text.strip()
+            if text.startswith('Author: '):
+                novel.author = text.strip('Author: ')
+            elif text.startswith('Tags: '):
+                for text in text.strip('Tags: ').split(','):
+                    novel.metadata.append(Metadata('subject', text.strip()))
 
         # other contributors
         for a in soup.select('.pp-multiple-authors-wrapper .author'):
-            metadata.append(Metadata('contributor', a.text.strip()))
+            novel.metadata.append(Metadata('contributor', a.text.strip()))
 
-        chapters = []
+        volume = novel.get_default_volume()
         for a in soup.select('.pt-cv-page > div a'):
             chapter = Chapter(
-                index=len(chapters),
+                index=len(volume.chapters),
                 title=a.text.strip(),
                 url=a['href'],
             )
 
-            chapters.append(chapter)
+            volume.chapters.append(chapter)
 
-        return novel, chapters, metadata
+        return novel
 
     def chapter(self, chapter: Chapter):
         soup = self.get_soup(chapter.url)
